==> papers-47.0-2-aarch64.pkg.tar.xz: usr/include/papers/4.0/papers-view.h <==
/*
* Copyright © 2009 Christian Persch
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#pragma once

#define __PPS_PAPERS_VIEW_H_INSIDE__

#ifndef I_KNOW_THE_PAPERS_LIBS_ARE_UNSTABLE_AND_HAVE_TALKED_WITH_THE_AUTHORS
#error You have to define I_KNOW_THE_PAPERS_LIBS_ARE_UNSTABLE_AND_HAVE_TALKED_WITH_THE_AUTHORS. And please! Contact the authors
#endif

#include <context/pps-attachment-context.h>
#include <libview/context/pps-bookmarks.h>
#include <libview/context/pps-document-model.h>
#include <libview/context/pps-history.h>
#include <libview/context/pps-metadata.h>
#include <libview/context/pps-search-context.h>
#include <libview/context/pps-search-result.h>

#include <libview/pps-job-scheduler.h>
#include <libview/pps-job.h>
#include <libview/pps-jobs.h>
#include <libview/pps-print-operation.h>
#include <libview/pps-view.h>
#include <libview/pps-view-type-builtins.h>

#undef __PPS_PAPERS_VIEW_H_INSIDE__

==> papers-48.5-1-aarch64.pkg.tar.xz: usr/include/papers/4.0/papers-view.h <==
/*
 * Copyright © 2009 Christian Persch
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by the
 * Free Software Foundation; either version 2.1 of the License, or (at your
 * option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser
 * General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#pragma once

#define __PPS_PAPERS_VIEW_H_INSIDE__

#ifndef I_KNOW_THE_PAPERS_LIBS_ARE_UNSTABLE_AND_HAVE_TALKED_WITH_THE_AUTHORS
#error You have to define I_KNOW_THE_PAPERS_LIBS_ARE_UNSTABLE_AND_HAVE_TALKED_WITH_THE_AUTHORS. And please! Contact the authors
#endif

#include <libview/context/pps-annotations-context.h>
#include <libview/context/pps-attachment-context.h>
#include <libview/context/pps-document-model.h>
#include <libview/context/pps-history.h>
#include <libview/context/pps-metadata.h>
#include <libview/context/pps-search-context.h>
#include <libview/context/pps-search-result.h>

#include <libview/pps-job-scheduler.h>
#include <libview/pps-job.h>
#include <libview/pps-jobs.h>
#include <libview/pps-print-operation.h>
#include <libview/pps-view-type-builtins.h>
#include <libview/pps-view.h>

#undef __PPS_PAPERS_VIEW_H_INSIDE__
